%define major	4.14

# "fix" underlinking:
%define _disable_ld_no_undefined 1


%bcond_with bootstrap

%ifarch %{ocaml_native_compiler}
%global native_compiler 1
%else
%global native_compiler 0
%endif

%global giturl https://github.com/ocaml/ocaml
#global rcver +git
%global rcver %{nil}

Name:		ocaml
Version:	5.3.0
Release:	%mkrel 6
Summary:	The OCaml compiler and programming environment
URL:		https://www.ocaml.org
VCS:		git:%{giturl}.git
License:	QPL with exceptions and LGPLv2 with exceptions
Group:		Development/OCaml
Source0:        https://github.com/ocaml/ocaml/archive/%{version}.tar.gz
Source1:	https://caml.inria.fr/pub/distrib/ocaml-%{major}/%{name}-%{major}-refman-html.tar.gz
Source2:        macros.ocaml-rpm
Source3:        ocaml_files.py

# IMPORTANT: 
# The contents (META's files) of this tarball comes from findlib
# This tarball have to be updated when findlib or ocaml are updated to a
# new version these META's files are only generated by the ./configure in
# the findlib source directory (ocaml-x11
# and ocaml-compiler-libs have to be installed for this operation) then
# just: 
# tar cfj findlib-1.4-ocaml-4.00.1-meta-files.tar.bz2 site-lib-src/*/META
Source5:	findlib-1.9.1-ocaml-%{version}-meta-files.tar.bz2

Patch0001:      0001-Don-t-add-rpaths-to-libraries.patch
Patch0002:      0002-configure-Allow-user-defined-C-compiler-flags.patch
Patch0003:      0003-configure-Remove-incorrect-assumption-about-cross-co.patch

# Workaround for upstream https://caml.inria.fr/mantis/view.php?id=5753
# Remove ocamltoplevel.cmxa from META file
Source19:	ocaml-4.00.1-fix-META-ocamltoplevel.cmxa.patch

BuildRequires: make
BuildRequires:  git
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	tcl
BuildRequires:	pkgconfig(tcl)
BuildRequires:	tk
BuildRequires:	pkgconfig(tk)
# So that ocamlobjinfo has bfd support
BuildRequires:  binutils-devel
# On 32 bits architectures it uses libatomic
%ifarch %arm %ix86 
BuildRequires:  devel(libatomic)
%endif
BuildRequires:  pkgconfig(libzstd)

# This BR is to enable automatic provides generation for this package.
# It can be removed safely if we need to bootstrap.
%if ! %with bootstrap
BuildRequires:  ocaml-compiler
%endif

Requires:	ncurses-devel
%if ! %with bootstrap
Requires:	ocaml-compiler = %{version}
%endif

Obsoletes:	ocaml-emacs < %{version}
Provides:	ocaml-emacs = %{version}

%if %{native_compiler}
%global __ocaml_requires_opts -c -f '%{buildroot}%{_bindir}/ocamlrun %{buildroot}%{_bindir}/ocamlobjinfo.byte' -i Dynlink_cmo_format -i Dynlink_cmxs_format
%else
%global __ocaml_requires_opts -c -f '%{buildroot}%{_bindir}/ocamlrun %{buildroot}%{_bindir}/ocamlobjinfo.byte' -i Backend_intf -i Inlining_decision_intf -i Simplify_boxed_integer_ops_intf -i Dynlink_cmo_format -i Dynlink_cmxs_format
%endif
%global __ocaml_provides_opts -f '%{buildroot}%{_bindir}/ocamlrun %{buildroot}%{_bindir}/ocamlobjinfo.byte'

%package	compiler
Summary:	Compiler and Runtime for OCaml
Group:		Development/OCaml
Conflicts:	ocaml < 3.12.1-7
Provides:       ocaml(compiler) = %{version}
Provides:       ocaml(runtime) = %{version}
Provides:       ocaml-uchar = %{version}
Obsoletes:      ocaml-uchar < %{version}
Provides:       ocaml-ocamldoc = %{version}-%{release}
Requires:       pkgconfig(libzstd)
%ifarch %arm %ix86 
Requires:       devel(libatomic)
%endif

%package	doc
Summary:	Documentation for OCaml
Group:		Documentation
BuildArch:	noarch
Requires:	%{name}-compiler = %{version}

%package sources
Summary:	OCaml sources
Group:		Development/OCaml
BuildArch:	noarch

%package compiler-libs
Summary:	OCaml compiler library
Group:		Development/OCaml
Requires:	%{name}-compiler = %{version}

%description
OCaml is a high-level, strongly-typed, functional and object-oriented
programming language from the ML family of languages.

%description compiler
This package comprises two batch OCaml compilers (a fast byte-code compiler and an
optimizing native-code compiler), an interactive top-level system, Lex&Yacc
tools, a replay debugger, and a comprehensive library.

%description	doc
Documentation for OCaml

%description sources
OCaml sources

%description compiler-libs
This package contains several modules used internally by the OCaml
compilers.  They are not needed for normal OCaml development, but may
be helpful in the development of certain applications.

%package rpm-macros
# LGPL-2.1-or-later WITH OCaml-LGPL-linking-exception: the project as a whole
# BSD-3-Clause: ocaml_files.py
License:        LGPL-2.1-or-later WITH OCaml-LGPL-linking-exception AND BSD-3-Clause
Summary:        RPM macros for building OCaml packages
BuildArch:      noarch
Requires:       ocaml = %{version}-%{release}
Requires:       python3
# ocaml_files.py used to be in ocaml-srpm-macros
Conflicts:      ocaml-srpm-macros < 10


%description rpm-macros
This package contains macros that are useful for building OCaml RPMs.

%prep
%autosetup -S git -n %{name}-%{version}%{rcver}
%setup -q -T -D -a 1 -n %{name}-%{version}%{rcver}
%setup -q -T -D -a 5 -n %{name}-%{version}%{rcver}
# Patches touch configure.ac, so rebuild it:
autoconf --force

%build
%ifnarch %{no_parallel_build_arches}
make="%make_build"
%else
unset MAKEFLAGS
make=make
%endif

sed -i '/ld_opts/s|\[\]|["%{build_ldflags}"]|' tools/ocamlmklib.ml

# We set --libdir to the unusual directory because we want OCaml to
# install its libraries and other files into a subdirectory.
#
# Force --host because of:
# https://lists.fedoraproject.org/archives/list/devel@lists.fedoraproject.org/thread/2O4HBOK6PTQZAFAVIRDVMZGG2PYB2QHM/
# (see also https://github.com/ocaml/ocaml/issues/8647)
#
# OC_CFLAGS/OC_LDFLAGS control what flags OCaml passes to the linker
# when doing final linking of OCaml binaries.  Setting these is
# necessary to ensure that generated binaries have Fedora hardening
# features.
%configure \
    OC_CFLAGS="$CFLAGS" \
    OC_LDFLAGS="$LDFLAGS" \
%if %{native_compiler}
    --enable-native-compiler \
    --enable-native-toplevel \
%else
    --disable-native-compiler \
    --disable-native-toplevel \
%endif
    --libdir=%{_libdir}/ocaml \
    --host=`./build-aux/config.guess`

$make world
%if %{native_compiler}
$make opt
$make opt.opt
%endif

%install
%make_install

# fix
perl -pi -e "s|%{buildroot}||" %{buildroot}%{_libdir}/ocaml/ld.conf

%ifarch %{ocaml_native_compiler}
# only keep the binary versions, which are much faster
for i in %{buildroot}%{_bindir}/*.opt ; do
  ln -sf `basename $i` ${i%.opt}
done
%endif

# install findlib META files
cp -pr site-lib-src/* %{buildroot}%{_libdir}/ocaml/

# fix me: this one should not be in the input
if [ -f %{buildroot}%{_libdir}/ocaml/dbm/META ]
then rm -f %{buildroot}%{_libdir}/ocaml/dbm/META; fi
# likewise, conflicts with ocaml-num:
rm -fr %{buildroot}%{_libdir}/ocaml/num{,-top}/


rm -f %{name}.list
n="graphics|X11"
(cd %{buildroot} ; find usr/bin ! -type d -printf "/%%p\n" | grep -v -E $n) >> %{name}.list
(cd %{buildroot} ; find usr/%{_lib}/ocaml ! -type d -printf "/%%p\n" | grep -v -E $n) >> %{name}.list
(cd %{buildroot} ; find usr/%{_lib}/ocaml   -type d -printf "%%%%dir /%%p\n" | grep -v -E $n) >> %{name}.list
fgrep \.cmt %{name}.list > cmt+cmti.list
sed -i '/\.cmt/d' %{name}.list

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=OCaml
Comment=ML language implementation with a class-based object system
Comment[fr]=mise en oeuvre de Meta Language (ML) avec un système orienté
Comment[ru]=Реализация языка ML с объектно-ориентированным подходом
GenericName=OCaml compiler and programming environment
GenericName[fr]=Environnement de programmation et compilateur OCaml
GenericName[ru]=Компилятор OCaml и среда программирования
Exec=%{name}
Icon=development_tools_section
Terminal=true
Type=Application
Categories=Development;
EOF


# install sources
install -d -m 755 %{buildroot}%{_prefix}/src
zcat %{SOURCE0} | tar xvf - -C %{buildroot}%{_prefix}/src
mv %{buildroot}%{_prefix}/src/%{name}-%{version}%{?rcver:%rcver} %{buildroot}%{_prefix}/src/%{name}

rm -f %{buildroot}%{_libdir}/ocaml/graphics/META
rm -rf %{buildroot}%{_datadir}/doc/ocaml

mkdir -p %{buildroot}%{_rpmmacrodir}
install -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{_rpmmacrodir}/macros.ocaml-rpm

mkdir -p %{buildroot}%{_rpmconfigdir}/redhat
install -m 0644 %{SOURCE3} $RPM_BUILD_ROOT%{_rpmconfigdir}/redhat

%files

%files compiler -f %{name}.list
%doc Changes LICENSE README.adoc 
%{_mandir}/man1/*
%{_datadir}/applications/*
%exclude %{_libdir}/ocaml/compiler-libs

%files doc
%doc htmlman/* 
%{_mandir}/man3/*

%files sources -f cmt+cmti.list
%{_prefix}/src/%{name}

%files compiler-libs
%dir %{_libdir}/ocaml/compiler-libs
%{_libdir}/ocaml/compiler-libs/META
%{_libdir}/ocaml/compiler-libs/*.cmi
%{_libdir}/ocaml/compiler-libs/*.cmo
%{_libdir}/ocaml/compiler-libs/*.cma
%if %{native_compiler}
%{_libdir}/ocaml/compiler-libs/*.a
%{_libdir}/ocaml/compiler-libs/*.cmxa
%{_libdir}/ocaml/compiler-libs/*.cmx
%{_libdir}/ocaml/compiler-libs/*.o
%endif

%files rpm-macros
%{_rpmmacrodir}/macros.ocaml-rpm
%{_rpmconfigdir}/redhat/ocaml_files.py


%changelog
* Mon Jul 07 2025 umeabot <umeabot> 5.3.0-6.mga10
+ Revision: 2250378
- Mageia 10 Mass Rebuild

* Wed Apr 02 2025 pterjan <pterjan> 5.3.0-5.mga10
+ Revision: 2172577
- Add missing conflicts

* Tue Apr 01 2025 pterjan <pterjan> 5.3.0-4.mga10
+ Revision: 2172560
- Add ocaml-rpm-macros from Fedora, it is convenient to bootstrap without opam
- Switch back to 5.3.0, updating opam with old versions is not easier than bootsraping everything with the new ones

* Mon Mar 31 2025 pterjan <pterjan> 4.14.0-6.mga10
+ Revision: 2172275
- Rebuild again, ocaml-srpm-macros had not be properly rolled back

* Mon Mar 31 2025 pterjan <pterjan> 4.14.0-5.mga10
+ Revision: 2172108
- Rebuild to use native compiler again on 32 bits architectures, this should only change after we update to 5.x to avoid an extra rebuild

* Mon Mar 31 2025 pterjan <pterjan> 4.14.0-4.mga10
+ Revision: 2172036
- Fix requires

* Mon Mar 31 2025 pterjan <pterjan> 4.14.0-3.mga10
+ Revision: 2172027
- Use build_ldflags
- Revert to 4.14.0 to add some fixes in core/release and allow updating opam before switching to new ocaml

* Sun Mar 30 2025 pterjan <pterjan> 5.3.0-3.mga10
+ Revision: 2171452
- Require in the compiler some libs it tries to link everything against

* Sat Mar 29 2025 pterjan <pterjan> 5.3.0-2.mga10
+ Revision: 2171437
- Try to fix Requires on 32 bits

* Sat Mar 29 2025 pterjan <pterjan> 5.3.0-1.mga10
+ Revision: 2171429
- Fix build on 32 bit architectures
- Update to 5.3.0

* Wed May 18 2022 pterjan <pterjan> 4.14.0-2.mga9
+ Revision: 1858729
- Update META files from findlib

* Wed May 18 2022 pterjan <pterjan> 4.14.0-1.mga9
+ Revision: 1858728
- Update to 4.14

* Tue Mar 29 2022 umeabot <umeabot> 4.13.1-2.mga9
+ Revision: 1831940
- Mageia 9 Mass Rebuild

* Tue Oct 12 2021 tv <tv> 4.13.1-1.mga9
+ Revision: 1750656
- OCaml 4.13.1 release
  https://ocaml.org/releases/4.13.0.html
- Move to final version of upstream patch for non-constant SIGSTKSZ

* Tue Mar 02 2021 tv <tv> 4.12.0-1.mga9
+ Revision: 1696160
- OCaml 4.12.0 release
  https://ocaml.org/releases/4.12.0.html
  https://ocaml.org/releases/4.11.0.html
- Workaround for glibc non-constant SIGSTKSZ
  (https://github.com/ocaml/ocaml/issues/10250)
- Move *.cmt and *.cmti files into source subpkg

* Mon Jan 11 2021 pterjan <pterjan> 4.10.0-4.mga8
+ Revision: 1671186
- Add BuildRequires binutils-devel

* Fri Aug 21 2020 umeabot <umeabot> 4.10.0-3.mga8
+ Revision: 1617556
- Rebuild for new ocaml deps generator

* Thu Apr 16 2020 pterjan <pterjan> 4.10.0-2.mga8
+ Revision: 1567884
- Drop RISC-V support, this causes a segfault on i586
+ tv <tv>
- update the building conditions
- Update all OCaml dependencies for RPM 4.16
- Fix RISC-V backend
- remove useless workaround

* Thu Feb 27 2020 pterjan <pterjan> 4.10.0-1.mga8
+ Revision: 1551103
- Update to 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 4.10.0-0.beta1.3.mga8
+ Revision: 1543227
- Mageia 8 Mass Rebuild
+ tv <tv>
- provides ocaml-ocamldoc

* Sun Jan 19 2020 tv <tv> 4.10.0-0.beta1.2.mga8
+ Revision: 1481491
- drop deps on ocaml-x11 which was dropped

* Sun Jan 19 2020 tv <tv> 4.10.0-0.beta1.1.mga8
+ Revision: 1481475
- non bootstrap build now that we've deps with proper version

* Sun Jan 19 2020 tv <tv> 4.10.0-0.beta1.mga8
+ Revision: 1481469
- bootstrap
- make sure to use just built ocaml to generate deps!
- OCaml 4.10.0+beta1

* Sun Jan 19 2020 tv <tv> 4.09.0-1.mga8
+ Revision: 1481452
- OCaml 4.09.0 final.
- Use autosetup, remove old setup line.
- Remove ocamloptp binaries.
- Rename target_camlheader[di] -> camlheader[di] files.
- Remove vmthreads - old threading library which is no longer built.
- Remove x11 subpackage which is obsolete.
- Further fixes to CFLAGS and annobin.
- Emacs subpackage has been dropped (from upstream)
- Better fix for armv7
- Disable underlinking
- we don't support alpha...

* Mon Oct 22 2018 pterjan <pterjan> 4.07.1-2.mga7
+ Revision: 1323982
- Rebuild without bootstrap

* Mon Oct 22 2018 pterjan <pterjan> 4.07.1-1.mga7
+ Revision: 1323960
- Update to 4.07.1 and fix floats on armv7hl
- Rebuild for ocaml 4.07

* Mon Oct 22 2018 pterjan <pterjan> 4.07.0-2.mga7
+ Revision: 1323678
- Rebuild without bootstrap

* Mon Oct 22 2018 pterjan <pterjan> 4.07.0-1.mga7
+ Revision: 1323642
- Update to 4.07

* Sun Sep 23 2018 umeabot <umeabot> 4.06.0-5.mga7
+ Revision: 1299828
- Mageia 7 Mass Rebuild

* Sat May 05 2018 daviddavid <daviddavid> 4.06.0-4.mga7
+ Revision: 1226232
- add upstream patch to fix CVE-2018-9838 (mga#22948)
+ wally <wally>
- build with host definition
+ tv <tv>
- obsoletes ocaml-uchar

* Mon Dec 04 2017 tv <tv> 4.06.0-3.mga7
+ Revision: 1181221
- fix conflicts with ocaml-num
- rebuild for new ocaml

* Sat Nov 25 2017 tv <tv> 4.06.0-1.2.mga7
+ Revision: 1179166
- enable ocaml deps
- add fixes from FC
- use %%autopatch

* Fri Nov 24 2017 tv <tv> 4.06.0-1.mga7
+ Revision: 1179120
- new release

* Sun Oct 08 2017 wally <wally> 4.02.3-7.mga7
+ Revision: 1170115
- add patch from Fedora to fix upstream bug 6517:
  'use standard ISO C99 types {,u}int{32,64}_t'

* Sun Sep 25 2016 pterjan <pterjan> 4.02.3-6.mga6
+ Revision: 1056219
- Rebuild for fix in ocaml

* Sun Sep 25 2016 pterjan <pterjan> 4.02.3-5.mga6
+ Revision: 1056109
- Add Fedora patch with the fix for http://openwall.com/lists/oss-security/2016/04/29/1 + other occurences of it, this will require rebuilding all ocaml packages (techincally only on x86_64)

* Tue Sep 20 2016 daviddavid <daviddavid> 4.02.3-4.mga6
+ Revision: 1054704
- fix desktop file icon not displayed on application menu entry
- add French translation of the desktop file

* Fri Jan 29 2016 pterjan <pterjan> 4.02.3-3.mga6
+ Revision: 928665
- Update META files

* Fri Jan 29 2016 pterjan <pterjan> 4.02.3-2.mga6
+ Revision: 928576
- Rebuild to hopefuly get correct provides

* Fri Jan 29 2016 pterjan <pterjan> 4.02.3-1.mga6
+ Revision: 928564
- Update to 4.02, camlp4 and labltk are now separate

* Mon Oct 19 2015 blino <blino> 4.01.0-13.mga6
+ Revision: 892861
- add a bootstrap flag to avoid buildrequiring self for the first build

* Sun Oct 04 2015 eatdirt <eatdirt> 4.01.0-12.mga6
+ Revision: 886239
- Rebuild for new tcl8.6

* Fri Nov 28 2014 alexl <alexl> 4.01.0-11.mga5
+ Revision: 799756
- new Comment for desktop file

* Sun Nov 23 2014 alexl <alexl> 4.01.0-10.mga5
+ Revision: 798422
- add GenericName
- translate desktop file into Russian

* Wed Oct 15 2014 umeabot <umeabot> 4.01.0-9.mga5
+ Revision: 744270
- Second Mageia 5 Mass Rebuild

* Mon Sep 22 2014 pterjan <pterjan> 4.01.0-8.mga5
+ Revision: 713461
- Try again fixing requires

* Sun Sep 21 2014 pterjan <pterjan> 4.01.0-7.mga5
+ Revision: 712104
- Try fixing requires

* Wed Sep 17 2014 malo <malo> 4.01.0-6.mga5
+ Revision: 691656
- add missing provides

* Wed Sep 17 2014 malo <malo> 4.01.0-5.mga5
+ Revision: 691426
- BuildRequires ocaml-compiler to automatically generate provides

* Tue Sep 16 2014 umeabot <umeabot> 4.01.0-4.mga5
+ Revision: 682973
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Sat Oct 19 2013 umeabot <umeabot> 4.01.0-3.mga4
+ Revision: 534514
- Mageia 4 Mass Rebuild

* Thu Sep 12 2013 blue_prawn <blue_prawn> 4.01.0-2.mga4
+ Revision: 478180
- updated to last version 4.01.0 (aka. Irène's release)

* Sat Sep 07 2013 blue_prawn <blue_prawn> 4.01.0-1.rc2.mga4
+ Revision: 475717
- updated to last RC version 4.01.0+rc2

* Wed Jul 31 2013 blue_prawn <blue_prawn> 4.00.1-8.mga4
+ Revision: 461612
- updated META files from findlib 1.4
- updated META files from findlib 1.4

* Sun Jun 09 2013 fwang <fwang> 4.00.1-7.mga4
+ Revision: 441006
- only libx11 is required

* Sat Mar 09 2013 rtp <rtp> 4.00.1-6.mga3
+ Revision: 401972
- fix build with ocaml opt disabled
- enable ocaml opt on arm as native arm eabi soft float is there now

* Sat Jan 19 2013 malo <malo> 4.00.1-5.mga3
+ Revision: 389843
- add patch to compiler-libs META file to workaround upstream bug 5753

* Sat Jan 12 2013 umeabot <umeabot> 4.00.1-4.mga3
+ Revision: 361116
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 23 2012 blue_prawn <blue_prawn> 4.00.1-3.mga3
+ Revision: 321414
- the file +dbm/META should not be included

* Tue Nov 20 2012 blue_prawn <blue_prawn> 4.00.1-2.mga3
+ Revision: 319735
- libdb is not used anymore
- libdb is not used anymore

* Fri Oct 05 2012 blue_prawn <blue_prawn> 4.00.1-1.mga3
+ Revision: 302936
- update to last version 4.00.1

* Mon Oct 01 2012 blue_prawn <blue_prawn> 4.00.0-4.mga3
+ Revision: 301268
- needs to be rebuilt
- removed old comments

* Mon Oct 01 2012 blue_prawn <blue_prawn> 4.00.0-3.mga3
+ Revision: 301136
- dbm has disappeared, don't require it
- dbm has disappeared, don't require it

* Sun Sep 30 2012 blue_prawn <blue_prawn> 4.00.0-2.mga3
+ Revision: 301066
- build with patches
- adapt patch9 for ocaml 4.00.0
- adapt patch6 for ocaml 4.00.0
- dbm is not in the main distribution anymore (it is released separated now)

* Sun Sep 30 2012 malo <malo> 4.00.0-1.mga3
+ Revision: 301001
- update to new version 4.00.0
+ blue_prawn <blue_prawn>
- new rpm group for ocaml

* Mon Sep 03 2012 blue_prawn <blue_prawn> 3.12.1-12.mga3
+ Revision: 287681
- removed dependency on libX11.so from the ocaml-compiler split (the related files have been put in the ocaml-x11 split)
- put the file compiler-libs/META in the right split

* Mon Aug 06 2012 blue_prawn <blue_prawn> 3.12.1-11.mga3
+ Revision: 279313
- added the split "ocaml-compiler-libs" needed by some packages
- The name "Objective Caml" shouldn't be used anymore, we should use only "OCaml" now (as decided by the community)

* Tue Jul 31 2012 fwang <fwang> 3.12.1-10.mga3
+ Revision: 276433
- force system db devel package

* Tue Jul 31 2012 fwang <fwang> 3.12.1-9.mga3
+ Revision: 276392
- build with db 5.3

* Sat Jul 21 2012 malo <malo> 3.12.1-8.mga3
+ Revision: 273107
- update for new findlib 1.3.3

* Fri Jul 20 2012 malo <malo> 3.12.1-7.mga3
+ Revision: 272951
- fix X11-devel dependency
- split ocaml into ocaml-compiler, ocaml-x11 and ocaml-dbm in order to remove
  the chain of requires: ocaml-compiler does not need x11.

* Thu Jun 14 2012 tv <tv> 3.12.1-6.mga3
+ Revision: 260492
- fix requires

* Thu Jun 14 2012 tv <tv> 3.12.1-5.mga3
+ Revision: 260477
- build with db5.2

* Thu Mar 08 2012 malo <malo> 3.12.1-4.mga2
+ Revision: 221439
- fix desktop file (mga#3635)
+ blue_prawn <blue_prawn>
- updated META files from new findlib 1.2.8
- Mageia SPEC syntax policy

* Sun Dec 04 2011 malo <malo> 3.12.1-3.mga2
+ Revision: 176299
- missing requires to libx11-devel, db4-devel, ncurses-devel
- splitting camlp4 with devel package, per Ocaml policy

* Sat Dec 03 2011 malo <malo> 3.12.1-2.mga2
+ Revision: 175622
- Fix file duplication in ocaml, camlp4 and ocaml-labltk
- spec cleanup

* Sat Oct 01 2011 shlomif <shlomif> 3.12.1-1.mga2
+ Revision: 150784
- Version 3.12.1 - thanks to Malo.

* Sat Jul 02 2011 fwang <fwang> 3.12.0-3.mga2
+ Revision: 117454
- Adding upstream patch fixing bad interactions between ocaml and binutils 2.21 (see http://caml.inria.fr/mantis/view.php?id=5237)

* Tue Apr 12 2011 ennael <ennael> 3.12.0-2.mga1
+ Revision: 83719
- add missing provides
+ ahmad <ahmad>
- imported package ocaml


* Sat Aug 28 2010 Florent Monnier <blue_prawn@mandriva.org> 3.12.0-1mdv2011.0
+ Revision: 573767
- updated to last version 3.12.0

* Mon Aug 23 2010 Florent Monnier <blue_prawn@mandriva.org> 3.11.2-4mdv2011.0
+ Revision: 572373
- updated META files provided by findlib version 1.2.6

* Mon Mar 01 2010 Guillaume Rousse <guillomovitch@mandriva.org> 3.11.2-3mdv2010.1
+ Revision: 512981
- fix camlp4 META file correctly

* Mon Mar 01 2010 Guillaume Rousse <guillomovitch@mandriva.org> 3.11.2-2mdv2010.1
+ Revision: 512910
- emacs is insufficient to compile bytecode, switch to full emacs
- fix incorrect META file for camlp4 on x86_64
- new version

* Fri Jan 01 2010 Oden Eriksson <oeriksson@mandriva.com> 3.11.1-5mdv2010.1
+ Revision: 484726
- rebuilt against bdb 4.8

* Sun Sep 27 2009 Olivier Blin <oblin@mandriva.com> 3.11.1-4mdv2010.0
+ Revision: 450174
- disable ocaml.opt* on mips & arm, not supported
  (from Arnaud Patard)

* Fri Sep 11 2009 Florent Monnier <blue_prawn@mandriva.org> 3.11.1-3mdv2010.0
+ Revision: 438520
- restore the previous solution to manage META files (sync for the tarball)
- restore the previous solution to manage META files

* Wed Sep 09 2009 Florent Monnier <blue_prawn@mandriva.org> 3.11.1-2mdv2010.0
+ Revision: 435818
- this tarball was not updated when ocaml and ocaml-findlib was updated,
  and there are currently things broken with this old tarball,
  instead of updating it, I think it's better to keep it in findlib where it's easier to keep it maintained

* Thu Jun 25 2009 Frederik Himpe <fhimpe@mandriva.org> 3.11.1-1mdv2010.0
+ Revision: 389199
- update to new version 3.11.1

* Wed Dec 24 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.11.0-2mdv2009.1
+ Revision: 318162
- rediff fuzzy patches
- site-lib hierarchy doesn't exist anymore

* Mon Dec 08 2008 Pixel <pixel@mandriva.com> 3.11.0-1mdv2009.1
+ Revision: 311906
- 3.11.0
- rediff/adapt patch9 (tk)

* Sat Dec 06 2008 Adam Williamson <awilliamson@mandriva.org> 3.10.2-5mdv2009.1
+ Revision: 310971
- rebuild for new tcl
- update tcl handling patch for 8.6
- new license policy

* Mon Sep 15 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.10.2-4mdv2009.0
+ Revision: 284872
- keep both bytecode and native versions for camlp4, as native ones have troubles with dynamic loading

* Mon Sep 01 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.10.2-3mdv2009.0
+ Revision: 278643
- re-enable optimized versions of camlp4

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 3.10.2-2mdv2009.0
+ Revision: 223356
- rebuild

* Sun Mar 02 2008 Stefan van der Eijk <stefan@mandriva.org> 3.10.2-1mdv2008.1
+ Revision: 177752
- 3.10.2, as per bug 37508

* Thu Dec 27 2007 Oden Eriksson <oeriksson@mandriva.com> 3.10.0-5mdv2008.1
+ Revision: 138206
- rebuilt against bdb 4.6.x libs

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Sep 07 2007 Anssi Hannula <anssi@mandriva.org> 3.10.0-4mdv2008.0
+ Revision: 82024
- rebuild for new soname of tcl

* Sun Sep 02 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.10.0-3mdv2008.0
+ Revision: 78255
- disable automatic dependencies for source package

* Sat Sep 01 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.10.0-2mdv2008.0
+ Revision: 77694
- add an ocaml-sources subpackage for cduce

* Tue May 29 2007 Pixel <pixel@mandriva.com> 3.10.0-1mdv2008.0
+ Revision: 32452
- new release, 3.10.0
- handle tk 8.5


* Tue Feb 20 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.09.3-5mdv2007.0
+ Revision: 123095
- use relative directory notation for camlp4 META file, so as to fix x86_64 usage

* Tue Feb 20 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.09.3-4mdv2007.1
+ Revision: 123047
- minor spec cleanup
- make sure shared libs under site-lib are available for loading

* Thu Jan 25 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.09.3-3mdv2007.1
+ Revision: 113230
- only ships META files for standard library, not findlib library itself

* Wed Jan 24 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.09.3-2mdv2007.1
+ Revision: 112752
- ensure emacs bytecode file are compiled in build dir, to avoid wrong files in install dir
- oops, increment release, not minor version
- spec file cleanup
- ship META files for findlib
- rename ocamltk package to ocaml-labltk

  + Crispin Boylan <crisb@mandriva.org>
    - Add patch to use db4 (closes #27858)

  + Gwenole Beauchesne <gbeauchesne@mandriva.com>
    - ppc64 fixes
    - 3.09.3
    - Import ocaml

* Thu Sep 21 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 3.09.2-4mdv2007.0
- improve lib64 patch for X.org 7.1 paths

* Thu Sep 21 2006 Nicolas Lécureuil <neoclust@mandriva.org> 3.09.2-3mdv2007.0
-  Rebuild against ncurse

* Sat May 20 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.09.2-2mdk
- ocaml-camltk requires tk-devel

* Tue Apr 25 2006 Pixel <pixel@mandriva.com> 3.09.2-1mdk
- new release

* Fri Jan 13 2006 Pixel <pixel@mandriva.com> 3.09.1-2mdk
- fix typo :-(

* Fri Jan 13 2006 Pixel <pixel@mandriva.com> 3.09.1-1mdk
- new release

* Mon Jan 02 2006 Oden Eriksson <oeriksson@mandriva.com> 3.09.0-2mdk
- rebuilt against soname aware deps (tcl/tk)
- fix deps

* Thu Nov 03 2005 Pixel <pixel@mandriva.com> 3.09.0-1mdk 
- new release
- drop add-warning-for-unused-local-variables patch
  (included upstream, neatly called warning "Z" :)

* Wed Apr 27 2005 Per Øyvind Karlsen <peroyvind@mandriva.org> 3.08.3-2mdk
- fix buildrequires
- %%mkrel

* Wed Apr 27 2005 Per Øyvind Karlsen <peroyvind@mandriva.org> 3.08.3-1mdk
- 3.08.3
- cosmetics

* Wed Dec 01 2004 Guillaume Rousse <guillomovitch@mandrake.org> 3.08.2-1mdk 
- new release
- removed packager tag
- rpmbuildupdate aware

* Tue Nov 09 2004 Pixel <pixel@mandrakesoft.com> 3.08.1-1mdk
- new release

* Fri Jul 16 2004 Pixel <pixel@mandrakesoft.com> 3.08-3mdk
- new release

* Tue Jun 29 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 3.07.2-3mdk
- BuildRequires: tcl

* Sat Apr 17 2004 Pixel <pixel@mandrakesoft.com> 3.07.2-2mdk
- don't modify BYTECCCOMPOPTS and NATIVECCCOMPOPTS, otherwise
  -D_FILE_OFFSET_BITS=64 is dropped (bugzilla #9502)
  => don't pass optflags (hope it won't break AXP which needs -mieee)
- have less warnings when compiling

